@@ -1,5 +1,5 @@
 from airflow.plugins_manager import AirflowPlugin
-import listener
+from odd_airflow_integration import listener
 
 
 class OddPlugin(AirflowPlugin):
